@@ -2,7 +2,7 @@ def gc(odb, used, jobs=None, cache_odb=None, shallow=True):
     from dvc_objects.errors import ObjectDBPermissionError
 
     from ._progress import QueryingProgress
-    from .tree import Tree
+    from .objects.tree import Tree
 
     if odb.read_only:
         raise ObjectDBPermissionError("Cannot gc read-only ODB")
@@ -18,7 +18,7 @@ def gc(odb, used, jobs=None, cache_odb=None, shallow=True):
             )
 
     def _is_dir_hash(_hash):
-        from dvc_objects.hash_info import HASH_DIR_SUFFIX
+        from dvc_objects.hashfile.hash_info import HASH_DIR_SUFFIX
 
         return _hash.endswith(HASH_DIR_SUFFIX)
 
